#!/bin/bash

###GAD PIPELINE ###
## haplo_scan.sh
## Version : 1.0.0
## Description : This scprit tke a bam and return a file text with HLA type
## Usage : qsub -v BAM=<path to the bam>,SORTIE=<path to outdir>,GeneList=<path to gene list>,[LOGFILE=/path/to/the/log/file] haplo_scan.sh
## Output : file text
## Requirements : HLAscan

## Author : Simon.Verdez@etu.u-bourgogne.fr
## Creation Date : 20180425
## last revision date : 20180425
## Known bugs : None

#$ -N hlascan
#$ -q batch
#$ -pe smp 2
#$ -V

# Log file path option
if [ -z ${LOGFILE} ]
then
    LOGFILE=haplo_scan.$(date +"%F_%H-%M-%S").log
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if input file exist
if [ ! -f $BAM ]
then
    echo "Bam file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch haplo_scan.failed
    exit 1
fi

# Check if gene file exist
if [ ! -f $GeneList ]
then
    echo "Gene file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch haplo_scan.failed
    exit 1
fi

# Check if config file exist
if [ ! -f $CONFIGFILE ]
then
    echo "Config file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_variants_snpeff.failed
    exit 1
fi

# Check if output file is specified
if [ -z $SORTIE ]
then
    echo "SORTIE file is not specified"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch haplo_scan.failed
    exit 1
fi

SAMPLE=`basename ${BAM} | cut -d . -f1`
RES=${SORTIE}
GL=/work/gad/shared/bin/HLAscan_v1.0/hla-ref-5gene/gene_list

#Launch haplo_scan
/work/gad/shared/bin/miniconda2/bin/python2.7 /work/gad/shared/bin/HLAscan_v1.0/hla-paper/haplo_scan_v4.0-sv.py $BAM $GL $RES

hla_exitcode=$?
echo "hla_scan exit code : $hla_exitcode"
if [ $hla_exitcode != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch hla_scan.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END"
